@@ -1,11 +1,11 @@
-#!/usr/bin/ruby -I/usr/share/apt-listbugs/
+#!/usr/bin/ruby
 
 ###
 ### test the relay with get_bugs->get_status.
 ###
 
-require 'debian/bts'
-require 'debian/btssoap'
+require 'aptlistbugs/debian/bts'
+require 'aptlistbugs/debian/btssoap'
 #$DEBUG=1
 soap=Debian::BTSSOAP::Soap.new
 pkglist = Debian::BTSSOAP::StringArray.new
