@@ -1,11 +1,11 @@
-#!/usr/bin/ruby -I/usr/share/apt-listbugs/
+#!/usr/bin/ruby
 
 ###
 ### test the get_bugs interface, which returns the bugs matching the key-id pair from the BTS.
 ###
 
-require 'debian/bts'
-require 'debian/btssoap'
+require 'aptlistbugs/debian/bts'
+require 'aptlistbugs/debian/btssoap'
 $DEBUG=1
 soap=Debian::BTSSOAP::Soap.new
 sa = Debian::BTSSOAP::StringArray.new
